#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/dialog.d/PGSQL_COMMON_PORT_CUI.sh - script dialog for ece
#
# Creation:     2019-03-17 hbfl
# Last update:  2023-07-23 09:11:10
#
# Copyright (c) 2019-2023 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

. /var/install/include/cuilib
. /var/install/include/ecelib

#----------------------------------------------------------------------------
# exec_dailog
# ece --> request to create and execute dialog
#         $p2 --> main window handle
#         $p3 --> name of config variable
#----------------------------------------------------------------------------
exec_dialog()
{
    win="$p2"

    pg_port='5432 5433 5434 5435 5436 5437 5438 5439 5440 5441'

    # get extra portlist if exists
    if [ -f '/etc/pgsql/portlist' ]
    then
        extra_port=$(cat /etc/pgsql/portlist)
        pg_port="${pg_port} ${extra_port}"
    fi

    pg_server=$(find /etc/config.d  -maxdepth 1 \
                -name 'postgresql' -printf '%f\n' -o \
                -name 'postgresql[0-9]*' -printf '%f\n')

    separator=''
    for PORT in ${pg_port}
    do
        p_list="${PORT}|available"

        for SERVER in ${pg_server}
        do
            . /etc/config.d/${SERVER}

            var_prefix=$(echo ${SERVER} | tr [:lower:] [:upper:])

            eval connect_port='${'${var_prefix}'_CONNECT_PORT}'

            if [ -z "${connect_port}" ]
            then
                eval connect_port='${'${var_prefix}'_SERVER_PORT}'
            fi

            if [ ${PORT:-0} -eq ${connect_port:-1} ]
            then
                p_list="${PORT}|${SERVER}"
                continue
            fi
        done

        sellist="${sellist}${separator}${p_list}"
        separator=','
    done

    ece_comment_list_dlg "$win" "Port used by" "$sellist"
}

#----------------------------------------------------------------------------
# main routine
#----------------------------------------------------------------------------

cui_init
cui_run

#----------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------

exit 0
